@@ -7,8 +7,10 @@ import langchain_core
 from .lib import ChangeDirectoryAndPath, ModuleManager, wrapped_func
 import json
 
+bot_index  = 0
 
 def import_bot(bot_id):
+    global bot_index
     tool_base_path = "../"
     module_path = os.path.join(tool_base_path, bot_id)
     module_path = os.path.normpath(os.path.abspath(module_path))
@@ -23,27 +25,33 @@ def import_bot(bot_id):
             with open(info, "r", encoding="utf-8") as f:
                 info = json.load(f)
             name = info["name"]
-            module = importlib.import_module("bot_function")
-            chat_func = getattr(module, "chat")
-            random_name = "bot_" + bot_id[-8:]
-            # 定义函数的内容
+            random_name = "bot_" + str(bot_index)
+            bot_index += 1
             function_code = f"""
 def {random_name}(command:str) -> str:
-    \"\"\"
-    本函数可以让你与虚拟人角色（{name}）进行交互。
-    该函数接收一个指令字符串，并返回虚拟人（{name}）执行该指令后的结果。
+    \"\"\"接收任意指令字符串，并返回AI角色（{name}专家）深入思考和执行指令后的字符串结果。
+    AI角色（{name}专家）擅长使用各种工具，并会给出专业且更为准确的结果。
 
     Args:
-        command: 需要执行的指令字符串。
+        command (str): AI角色（{name}专家）需要执行的指令字符串。
 
     Returns:
-        str: 虚拟人执行指令后的结果。
+        str: AI角色（{name}专家）执行指令后的结果。
     \"\"\"
-    return chat_func(command)
+    from pycoze import bot
+    from pycoze import utils
+    import tempfile
+    
+    with tempfile.NamedTemporaryFile(delete=True, mode='w+t') as temp_file:
+        sys.stdout = temp_file  # 将输出重定向到临时文件，防止影响AI结果
+        result = bot.get_chat_response("botSetting.json", command)
+        sys.stdout = sys.__stdout__  # 恢复标准输出
+    return result
 """
             exec(function_code)
-            print("docstring", eval(random_name).__doc__)
-            return wrapped_func(to_agent_tool(eval(random_name)), module_path)
+            tool = to_agent_tool(eval(random_name))
+            tool.func = wrapped_func(tool, module_path)
+            return tool
     except Exception as e:
         print(f"Error loading bot {bot_id}: {e}")
         return None
\ No newline at end of file
